==> open-cluster-management-observability-model-5.12.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/StorageConfigBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StorageConfigBuilder extends io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.StorageConfigFluentImpl<io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.StorageConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.StorageConfig,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.StorageConfigBuilder>{
  public StorageConfigBuilder() {
    this(false);
  }
  public StorageConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new StorageConfig(), validationEnabled);
  }
  public StorageConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.StorageConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.StorageConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StorageConfig(), validationEnabled);
  }
  public StorageConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.StorageConfigFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.StorageConfig instance) {
    this(fluent, instance, false);
  }
  public StorageConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.StorageConfigFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.StorageConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAlertmanagerStorageSize(instance.getAlertmanagerStorageSize()); 
    fluent.withCompactStorageSize(instance.getCompactStorageSize()); 
    fluent.withMetricObjectStorage(instance.getMetricObjectStorage()); 
    fluent.withReceiveStorageSize(instance.getReceiveStorageSize()); 
    fluent.withRuleStorageSize(instance.getRuleStorageSize()); 
    fluent.withStorageClass(instance.getStorageClass()); 
    fluent.withStoreStorageSize(instance.getStoreStorageSize()); 
    this.validationEnabled = validationEnabled; 
  }
  public StorageConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.StorageConfig instance) {
    this(instance,false);
  }
  public StorageConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.StorageConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAlertmanagerStorageSize(instance.getAlertmanagerStorageSize()); 
    this.withCompactStorageSize(instance.getCompactStorageSize()); 
    this.withMetricObjectStorage(instance.getMetricObjectStorage()); 
    this.withReceiveStorageSize(instance.getReceiveStorageSize()); 
    this.withRuleStorageSize(instance.getRuleStorageSize()); 
    this.withStorageClass(instance.getStorageClass()); 
    this.withStoreStorageSize(instance.getStoreStorageSize()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.StorageConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.StorageConfig build() {
    StorageConfig buildable = new StorageConfig(fluent.getAlertmanagerStorageSize(),fluent.getCompactStorageSize(),fluent.getMetricObjectStorage(),fluent.getReceiveStorageSize(),fluent.getRuleStorageSize(),fluent.getStorageClass(),fluent.getStoreStorageSize());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StorageConfigBuilder that = (StorageConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-observability-model-6.3.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/StorageConfigBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class StorageConfigBuilder extends StorageConfigFluentImpl<StorageConfigBuilder> implements VisitableBuilder<StorageConfig,StorageConfigBuilder>{
  public StorageConfigBuilder() {
    this(false);
  }
  public StorageConfigBuilder(Boolean validationEnabled) {
    this(new StorageConfig(), validationEnabled);
  }
  public StorageConfigBuilder(StorageConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageConfigBuilder(StorageConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new StorageConfig(), validationEnabled);
  }
  public StorageConfigBuilder(StorageConfigFluent<?> fluent,StorageConfig instance) {
    this(fluent, instance, false);
  }
  public StorageConfigBuilder(StorageConfigFluent<?> fluent,StorageConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAlertmanagerStorageSize(instance.getAlertmanagerStorageSize()); 
    fluent.withCompactStorageSize(instance.getCompactStorageSize()); 
    fluent.withMetricObjectStorage(instance.getMetricObjectStorage()); 
    fluent.withReceiveStorageSize(instance.getReceiveStorageSize()); 
    fluent.withRuleStorageSize(instance.getRuleStorageSize()); 
    fluent.withStorageClass(instance.getStorageClass()); 
    fluent.withStoreStorageSize(instance.getStoreStorageSize()); 
    this.validationEnabled = validationEnabled; 
  }
  public StorageConfigBuilder(StorageConfig instance) {
    this(instance,false);
  }
  public StorageConfigBuilder(StorageConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAlertmanagerStorageSize(instance.getAlertmanagerStorageSize()); 
    this.withCompactStorageSize(instance.getCompactStorageSize()); 
    this.withMetricObjectStorage(instance.getMetricObjectStorage()); 
    this.withReceiveStorageSize(instance.getReceiveStorageSize()); 
    this.withRuleStorageSize(instance.getRuleStorageSize()); 
    this.withStorageClass(instance.getStorageClass()); 
    this.withStoreStorageSize(instance.getStoreStorageSize()); 
    this.validationEnabled = validationEnabled; 
  }
  StorageConfigFluent<?> fluent;
  Boolean validationEnabled;
  public StorageConfig build() {
    StorageConfig buildable = new StorageConfig(fluent.getAlertmanagerStorageSize(),fluent.getCompactStorageSize(),fluent.getMetricObjectStorage(),fluent.getReceiveStorageSize(),fluent.getRuleStorageSize(),fluent.getStorageClass(),fluent.getStoreStorageSize());
    return buildable;
  }
  
}
